==> platform-module-5.4.240119-sources.jar: com/centit/locode/platform/po/AppInfo.java <==
package com.centit.locode.platform.po;

import com.centit.support.database.orm.GeneratorType;
import com.centit.support.database.orm.ValueGenerator;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

@ApiModel(value = "移动端版本管理信息", description = "移动端版本管理信息")
@Entity
@Data
@Table(name = "F_APP_INFO")
public class AppInfo implements Serializable {

    private static final long serialVersionUID = 1L;

    @Id
    @Column(name = "ID")
    @ValueGenerator(strategy = GeneratorType.UUID22)
    @Length(max = 32)
    @ApiModelProperty(value = "主键id", name = "id")
    private String id;

    @Column(name = "VERSION_ID")
    @Length(max = 32)
    @ApiModelProperty(value = "版本号", name = "versionId")
    private String versionId;

    @Column(name = "VERSION_DES")
    @Length(max = 500)
    @ApiModelProperty(value = "版本描述", name = "versionDes")
    private String versionDes;

    @Column(name = "APP_TYPE")
    @Length(max = 32)
    @ApiModelProperty(value = "设备类型", name = "appType")
    private String appType;

    @Column(name = "OWN_APP")
    @Length(max = 100)
    @ApiModelProperty(value = "所属应用", name = "ownApp")
    private String ownApp;

    @Column(name = "top_unit")
    @Length(max = 32)
    @ApiModelProperty(value = "所属租户", name = "topUnit")
    private String topUnit;

    @Column(name = "FILE_ID")
    @Length(max = 100)
    @ApiModelProperty(value = "文件Id", name = "fileId")
    private String fileId;

    @Column(name = "FILE_NAME")
    @Length(max = 100)
    @ApiModelProperty(value = "文件名称", name = "fileName")
    private String fileName;

    @Column(name = "FILE_URL")
    @Length(max = 500)
    @ApiModelProperty(value = "文件下载地址", name = "fileUrl")
    private String fileUrl;

    @Column(name = "CREATOR")
    @Length(max = 32)
    @ApiModelProperty(value = "申请人", name = "creator")
    private String creator;

    @Column(name = "CREATE_TIME")
    @ApiModelProperty(value = "创建时间", name = "createTime")
    @ValueGenerator(strategy = GeneratorType.FUNCTION, value = "today()")
    @OrderBy("DESC")
    private Date createTime;

}

==> platform-module-5.5-20251204.032507-126-sources.jar: com/centit/locode/platform/po/AppInfo.java <==
package com.centit.locode.platform.po;

import com.centit.support.database.orm.GeneratorType;
import com.centit.support.database.orm.ValueGenerator;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

@ApiModel(value = "移动端版本管理信息", description = "移动端版本管理信息")
@Entity
@Data
@Table(name = "F_APP_INFO")
public class AppInfo implements Serializable {

    private static final long serialVersionUID = 1L;

    @Id
    @Column(name = "ID")
    @ValueGenerator(strategy = GeneratorType.UUID22)
    @Length(max = 32)
    @ApiModelProperty(value = "主键id", name = "id")
    private String id;

    @Column(name = "VERSION_ID")
    @Length(max = 32)
    @ApiModelProperty(value = "版本号", name = "versionId")
    private String versionId;

    @Column(name = "VERSION_DES")
    @Length(max = 500)
    @ApiModelProperty(value = "版本描述", name = "versionDes")
    private String versionDes;

    @Column(name = "APP_TYPE")
    @Length(max = 32)
    @ApiModelProperty(value = "设备类型", name = "appType")
    private String appType;

    @Column(name = "OWN_APP")
    @Length(max = 100)
    @ApiModelProperty(value = "所属应用", name = "ownApp")
    private String ownApp;

    @Column(name = "top_unit")
    @Length(max = 32)
    @ApiModelProperty(value = "所属租户", name = "topUnit")
    private String topUnit;

    @Column(name = "FILE_ID")
    @Length(max = 100)
    @ApiModelProperty(value = "文件Id", name = "fileId")
    private String fileId;

    @Column(name = "FILE_SIZE")
    @ApiModelProperty(value = "文件大小", name = "fileSize")
    private Long fileSize;

    @Column(name = "FILE_NAME")
    @Length(max = 100)
    @ApiModelProperty(value = "文件名称", name = "fileName")
    private String fileName;

    @Column(name = "FILE_URL")
    @Length(max = 500)
    @ApiModelProperty(value = "文件下载地址", name = "fileUrl")
    private String fileUrl;

    @Column(name = "CREATOR")
    @Length(max = 32)
    @ApiModelProperty(value = "申请人", name = "creator")
    private String creator;

    @Column(name = "CREATE_TIME")
    @ApiModelProperty(value = "创建时间", name = "createTime")
    @ValueGenerator(strategy = GeneratorType.FUNCTION, value = "today()")
    @OrderBy("DESC")
    private Date createTime;

}
